import {
  CustomerService,
  Logger,
  NativeAuthenticationMethod
} from '@vendure/core';
import { emailVerificationHandler } from '@vendure/email-plugin';

export const userEmailVerificationHandler = emailVerificationHandler
  .setSubject(`DANSA | Please verify your email address`)
  .loadData(async ({ event, injector }) => {
    const customerService = injector.get(CustomerService);
    const customer = await customerService.findOneByUserId(event.ctx, event.user.id);

    if (!customer) {
      Logger.error(`User with ID ${event.user.id} not found`, 'userPasswordResetHandler');
      throw new Error(`User with ID ${event.user.id} not found`);
    }

    return { customer };
  })
  .filter((event) => !!event.user.getNativeAuthenticationMethod().identifier)
  .filter((event) => {
    const nativeAuthMethod = event.user.authenticationMethods.find(
      (m) => m instanceof NativeAuthenticationMethod
    ) as NativeAuthenticationMethod | undefined;
    return (nativeAuthMethod && !!nativeAuthMethod.identifier) || false;
  })
  .setRecipient((event) => event.user.identifier)
  .setTemplateVars((event) => {
    const customerFirstName = event.data.customer.firstName;
    const customerLastName = event.data.customer.lastName;
    return {
      verificationToken: event.user.getNativeAuthenticationMethod().verificationToken,
      customerFirstName,
      customerLastName
    };
  });
