import { Logger, OrderService } from '@vendure/core';
import { orderConfirmationHandler } from '@vendure/email-plugin';

export const userOrderConfirmationHandler = orderConfirmationHandler
  .setSubject(`DANSA | Payment Settled | Order #{{ orderCode }}`)
  .loadData(async ({ event, injector }) => {
    Logger.info(`Loading data for order confirmation`, 'userOrderConfirmationHandler');
    const orderService = injector.get(OrderService);
    const fullOrder = await orderService.findOne(event.ctx, event.order.id, [
      'lines',
      'lines.productVariant',
      'lines.featuredAsset',
      'customer',
      'payments',
      'shippingLines'
    ]);

    // Full Order
    if (!fullOrder) {
      Logger.error(`Order with ID ${event.order.id} not found`, 'user Order Confirmation Handler');
      // console.error(`Order with ID ${event.order.id} not found`, 'user Order Confirmation Handler');
      throw new Error(`Order with ID ${event.order.id} not found`);
    } else {
      Logger.info(
        `Order data loaded for order ${event.order.code}`,
        'user Order Confirmation Handler'
      );
      // console.log(`Order data loaded for order ${event.order.code}`, 'user Order Confirmation Handler');
    }
    return { fullOrder };
  })
  .setTemplateVars(({ data }) => {
    const { fullOrder } = data;
    // let currencySymbol = fullOrder.currencyCode;
    const currencySymbol = 'R'; // Default to Rand

    // matching the structure of template
    return {
      orderCode: fullOrder.code,
      order: {
        code: fullOrder.code,
        totalWithTax: fullOrder.totalWithTax,
        customer: {
          firstName: fullOrder.customer?.firstName,
          lastName: fullOrder.customer?.lastName
        },
        orderPlacedAt: fullOrder.orderPlacedAt,
        lines: fullOrder.lines,
        discounts: fullOrder.discounts,
        subTotalWithTax: fullOrder.subTotalWithTax,
        shippingAddress: fullOrder.shippingAddress,
        shippingLines: fullOrder.shippingLines,
        featuredAsset: fullOrder.lines[0].featuredAsset,
        currencySymbol
      },
      orderUrl: `http://157.245.36.128:5200/danshop/checkout/confirmation/${fullOrder.code}`
    };
  });
