import { CustomerService, Logger } from '@vendure/core';
import { passwordResetHandler } from '@vendure/email-plugin';

export const userPasswordResetHandler = passwordResetHandler
  .setSubject(`DANSA | Password Reset Instructions`)
  .loadData(async ({ event, injector }) => {
    const customerService = injector.get(CustomerService);
    const customer = await customerService.findOneByUserId(event.ctx, event.user.id);

    if (!customer) {
      Logger.error(`User with ID ${event.user.id} not found`, 'userPasswordResetHandler');
      throw new Error(`User with ID ${event.user.id} not found`);
    }

    return { customer };
  })
  .setTemplateVars((event) => {
    const customerFirstName = event.data.customer.firstName;
    const customerLastName = event.data.customer.lastName;

    return {
      passwordResetToken: event.user.getNativeAuthenticationMethod().passwordResetToken,
      customerFirstName,
      customerLastName
    };
  });
