import { Logger } from '@vendure/core';
import { EmailEventListener, EmailEventHandler } from '@vendure/email-plugin';

import { ContactSubmittedEvent } from '../events/contact-submitted.event';
import { AdminService } from '../services/admin-email.service';

let adminEmails: string[] = []; // To store fetched admin emails

export const contactFormHandler = new EmailEventListener('contact-form')
  .on(ContactSubmittedEvent)
  .setRecipient(() => {
    return adminEmails.join(',');
  })
  .setFrom('{{ fromAddress }}')
  .setSubject('DAN Store | New Contact Form Submission')
  .setTemplateVars(event => ({
    name: event.input.name,
    email: event.input.email,
    message: event.input.message,
  }));

// Auto-reply email event listener
export const autoReplyHandler = new EmailEventListener('contact-form-sender-auto-reply')
  .on(ContactSubmittedEvent)
  .setRecipient(event => {
    const recipient = event.input.email;
    Logger.info(`Setting recipient for auto-reply: ${recipient}`, 'ContactsPlugin');
    return recipient;
  })
  .setFrom('{{ fromAddress }}')
  .setSubject('Thank you for contacting us!')
  .setTemplateVars(event => {
    Logger.info(`Setting template variables for auto-reply: ${JSON.stringify(event.input, null, 2)}`, 'ContactsPlugin');
    return {
      name: event.input.name,
    };
  })

// Initialize the adminService and fetch emails
export async function initializeAdminService(service: AdminService) {
  adminEmails = await service.getAllAdminEmails();
  Logger.info(`Admin emails initialized: ${adminEmails.join(', ')}`, 'ContactsPlugin');
}