/* eslint-disable prettier/prettier */
import { Injectable } from '@nestjs/common';
import { EventBus, ID, Logger, RequestContext, TransactionalConnection } from '@vendure/core';

import { Contacts } from '../entities/contacts.entity';
import { ContactSubmittedEvent } from '../events/contact-submitted.event';
import { ContactFormInput } from '../types';

@Injectable()
export class ContactsService {
    constructor(
        private connection: TransactionalConnection,
        private eventBus: EventBus
    ) {}

    async submitContactsForm(ctx: RequestContext, input: ContactFormInput): Promise<Contacts> {
        const contactRepository = this.connection.rawConnection.getRepository(Contacts);
        const contact = await contactRepository.save(new Contacts({
            name: input.name,
            email: input.email,
            message: input.message,
        }));

        Logger.info(`Contact form saved: ${JSON.stringify(contact, null, 2)}`, 'ContactsService');
        
        await this.eventBus.publish(new ContactSubmittedEvent(ctx, input));
        return contact;
    }

    async findOne(id: ID): Promise<Contacts | null> {
        Logger.info(`Finding contact with ID: ${id}`, 'ContactService');
        
        const contactRepository = this.connection.rawConnection.getRepository(Contacts);
        const contact = await contactRepository.findOne({ where: { id } });
        
        Logger.info(`Contact found: ${JSON.stringify(contact, null, 2)}`, 'ContactService');
        
        return contact;
    }
}
