import { Logger } from '@vendure/core';
import { EmailEventListener, EmailEventHandler } from '@vendure/email-plugin';

import { ProductContactSubmittedEvent } from '../events/product-contact-submitted.event';
import { AdminService } from '../../EMAILS/store-contact/services/admin-email.service';

let adminEmails: string[] = []; // To store fetched admin emails

export const productContactFormHandler = new EmailEventListener('product-contact-form')
  .on(ProductContactSubmittedEvent)
  .setRecipient(() => {
    return adminEmails.join(',');
  })
  .setFrom('{{ fromAddress }}')
  .setSubject('DAN Store | New Product Contact Form Submission')
  .setTemplateVars(event => ({
    firstName: event.input.firstName,
    lastName: event.input.lastName,
    email: event.input.email,
    reason: event.input.reason,
    message: event.input.message,
    productVariantName: event.input.productVariantName,
  }));

// Auto-reply email event listener
export const productContactAutoReplyHandler = new EmailEventListener('product-contact-sender-auto-reply')
  .on(ProductContactSubmittedEvent)
  .setRecipient(event => {
    const recipient = event.input.email;
    Logger.info(`Setting recipient for auto-reply: ${recipient}`, 'ProductContactPlugin');
    return recipient;
  })
  .setFrom('{{ fromAddress }}')
  .setSubject('Thank you for contacting us!')
  .setTemplateVars(event => {
    Logger.info(`Setting template variables for auto-reply: ${JSON.stringify(event.input, null, 2)}`, 'ProductContactPlugin');
    return {
      firstName: event.input.firstName,
      lastName: event.input.lastName,
      email: event.input.email,
      reason: event.input.reason,
      message: event.input.message,
      productVariantName: event.input.productVariantName,
    };
  });

// Initialize the adminService and fetch emails
export async function initializeAdminService(service: AdminService) {
  adminEmails = await service.getAllAdminEmails();
  Logger.info(`Admin emails initialized: ${adminEmails.join(', ')}`, 'ProductContactPlugin');
}
