import { OnEvent } from '@nestjs/event-emitter';
import { Injectable } from '@nestjs/common';
import { FulfillmentService, OrderService, RequestContext } from '@vendure/core';
import { FulfillmentEvent } from '../events/fulfillment-event';
import { ConfigurableOperationInput } from '@vendure/common/lib/generated-types';

@Injectable()
export class FulfillmentSubscriber {
  constructor(
    private orderService: OrderService,
    private fulfillmentService: FulfillmentService
  ) {}

  @OnEvent('fulfillment.created')
  async handleFulfillmentEvent(event: FulfillmentEvent) {
    console.log('FulfillmentEvent received:', event);
    const { ctx, orderId } = event;
    const order = await this.orderService.findOne(ctx, orderId);
    if (order) {
      const lines = order.lines.map(line => ({
        orderLineId: line.id,
        quantity: line.quantity,
      }));

      const handler = {
        code: 'manual-fulfillment',
        arguments: [],
      };
      console.log('Creating fulfillment for order:', orderId); 
      await this.fulfillmentService.create(ctx, [order], lines, handler);
    } else {
      console.error(`Order with id ${orderId} not found`);
    }
  }
}
